@@ -91,6 +91,11 @@ class PHATE(BaseEstimator):
         `data[0,0]`. You can override this detection with
         `knn_dist='precomputed_distance'` or `knn_dist='precomputed_affinity'`.
 
+    knn_max : int, optional, default: None
+        Maximum number of neighbors for which alpha decaying kernel
+        is computed for each point. For very large datasets, setting `knn_max`
+        to a small multiple of `knn` can speed up computation significantly.
+
     mds_dist : string, optional, default: 'euclidean'
         Distance metric for MDS. Recommended values: 'euclidean' and 'cosine'
         Any metric from `scipy.spatial.distance` can be used. Custom distance
@@ -119,16 +124,6 @@ class PHATE(BaseEstimator):
         Use `gamma=1` for log transformation and `gamma=0` for square root
         transformation.
 
-    alpha_decay : deprecated.
-        Use `decay=None` to disable alpha decay
-
-    njobs : deprecated.
-        Use n_jobs to match `sklearn` standards
-
-    k : Deprecated for `knn`
-
-    a : Deprecated for `decay`
-
     kwargs : additional arguments for `graphtools.Graph`
 
     Attributes
@@ -139,9 +134,6 @@ class PHATE(BaseEstimator):
     embedding : array-like, shape=[n_samples, n_components]
         Stores the position of the dataset in the embedding space
 
-    diff_op :  array-like, shape=[n_samples, n_samples] or [n_landmark, n_landmark]
-        The diffusion operator built from the graph
-
     graph : graphtools.base.BaseGraph
         The graph built on the input data
 
@@ -182,22 +174,22 @@ class PHATE(BaseEstimator):
         n_pca=100,
         mds_solver="sgd",
         knn_dist="euclidean",
+        knn_max=None,
         mds_dist="euclidean",
         mds="metric",
         n_jobs=1,
         random_state=None,
         verbose=1,
-        potential_method=None,
-        alpha_decay=None,
-        njobs=None,
-        k=None,
-        a=None,
         **kwargs
     ):
-        if k is not None:
-            knn = k
-        if a is not None:
-            decay = a
+        if "k" in kwargs:
+            warnings.warn("k is deprecated. Please use knn in future.", FutureWarning)
+            knn = kwargs["k"]
+            del kwargs["k"]
+        if "a" in kwargs:
+            warnings.warn("a is deprecated. Please use decay in future.", FutureWarning)
+            decay = kwargs["a"]
+            del kwargs["a"]
         self.n_components = n_components
         self.decay = decay
         self.knn = knn
@@ -206,6 +198,7 @@ class PHATE(BaseEstimator):
         self.mds = mds
         self.n_pca = n_pca
         self.knn_dist = knn_dist
+        self.knn_max = knn_max
         self.mds_dist = mds_dist
         self.mds_solver = mds_solver
         self.random_state = random_state
@@ -217,40 +210,41 @@ class PHATE(BaseEstimator):
         self.X = None
         self.optimal_t = None
 
-        if (alpha_decay is True and decay is None) or (
-            alpha_decay is False and decay is not None
-        ):
+        if "alpha_decay" in kwargs:
             warnings.warn(
                 "alpha_decay is deprecated. Use `decay=None`"
                 " to disable alpha decay in future.",
                 FutureWarning,
             )
-            if not alpha_decay:
+            if not kwargs["alpha_decay"]:
                 self.decay = None
+            del kwargs["alpha_decay"]
 
-        if njobs is not None:
+        if "njobs" in kwargs:
             warnings.warn(
                 "njobs is deprecated. Please use n_jobs in future.", FutureWarning
             )
-            n_jobs = njobs
+            n_jobs = kwargs["njobs"]
+            del kwargs["njobs"]
         self.n_jobs = n_jobs
 
-        if potential_method is not None:
-            if potential_method == "log":
+        if "potential_method" in kwargs:
+            if kwargs["potential_method"] == "log":
                 gamma = 1
-            elif potential_method == "sqrt":
+            elif kwargs["potential_method"] == "sqrt":
                 gamma = 0
             else:
                 raise ValueError(
                     "potential_method {} not recognized. Please "
-                    "use gamma between -1 and 1".format(potential_method)
+                    "use gamma between -1 and 1".format(kwargs["potential_method"])
                 )
             warnings.warn(
                 "potential_method is deprecated. "
                 "Setting gamma to {} to achieve"
-                " {} transformation.".format(gamma, potential_method),
+                " {} transformation.".format(gamma, kwargs["potential_method"]),
                 FutureWarning,
             )
+            del kwargs["potential_method"]
         elif gamma > 0.99 and gamma < 1:
             warnings.warn(
                 "0.99 < gamma < 1 is numerically unstable. " "Setting gamma to 0.99",
@@ -269,7 +263,8 @@ class PHATE(BaseEstimator):
 
     @property
     def diff_op(self):
-        """The diffusion operator calculated from the data
+        """diff_op :  array-like, shape=[n_samples, n_samples] or [n_landmark, n_landmark]
+        The diffusion operator built from the graph
         """
         if self.graph is not None:
             if isinstance(self.graph, graphtools.graphs.LandmarkGraph):
@@ -313,16 +308,19 @@ class PHATE(BaseEstimator):
         ------
         ValueError : unacceptable choice of parameters
         """
-        utils.check_positive(n_components=self.n_components, k=self.knn)
-        utils.check_int(n_components=self.n_components, k=self.knn, n_jobs=self.n_jobs)
+        utils.check_positive(n_components=self.n_components, knn=self.knn)
+        utils.check_int(
+            n_components=self.n_components, knn=self.knn, n_jobs=self.n_jobs
+        )
         utils.check_between(-1, 1, gamma=self.gamma)
-        utils.check_if_not(None, utils.check_positive, a=self.decay)
+        utils.check_if_not(None, utils.check_positive, decay=self.decay)
         utils.check_if_not(
             None,
             utils.check_positive,
             utils.check_int,
             n_landmark=self.n_landmark,
             n_pca=self.n_pca,
+            knn_max=self.knn_max,
         )
         utils.check_if_not("auto", utils.check_positive, utils.check_int, t=self.t)
         if not callable(self.knn_dist):
@@ -462,6 +460,11 @@ class PHATE(BaseEstimator):
             using `data[0,0]`. You can override this detection with
             `knn_dist='precomputed_distance'` or `knn_dist='precomputed_affinity'`.
 
+        knn_max : int, optional, default: None
+            Maximum number of neighbors for which alpha decaying kernel
+            is computed for each point. For very large datasets, setting `knn_max`
+            to a small multiple of `knn` can speed up computation significantly.
+
         mds_dist : string, optional, default: 'euclidean'
             recommended values: 'euclidean' and 'cosine'
             Any metric from `scipy.spatial.distance` can be used
@@ -486,10 +489,6 @@ class PHATE(BaseEstimator):
         verbose : `int` or `boolean`, optional (default: 1)
             If `True` or `> 0`, print status messages
 
-        k : Deprecated for `knn`
-
-        a : Deprecated for `decay`
-
         Examples
         --------
         >>> import phate
@@ -498,14 +497,14 @@ class PHATE(BaseEstimator):
         ...                                               branch_length=50)
         >>> tree_data.shape
         (250, 50)
-        >>> phate_operator = phate.PHATE(k=5, a=20, t=150)
+        >>> phate_operator = phate.PHATE(knn=5, decay=20, t=150)
         >>> tree_phate = phate_operator.fit_transform(tree_data)
         >>> tree_phate.shape
         (250, 2)
         >>> phate_operator.set_params(n_components=10)
-        PHATE(a=20, alpha_decay=None, k=5, knn_dist='euclidean', mds='metric',
+        PHATE(decay=20, knn=5, knn_dist='euclidean', mds='metric',
            mds_dist='euclidean', n_components=10, n_jobs=1, n_landmark=2000,
-           n_pca=100, njobs=None, potential_method='log', random_state=None, t=150,
+           n_pca=100, potential_method='log', random_state=None, t=150,
            verbose=1)
         >>> tree_phate = phate_operator.transform()
         >>> tree_phate.shape
@@ -580,6 +579,10 @@ class PHATE(BaseEstimator):
             self.knn = params["knn"]
             reset_kernel = True
             del params["knn"]
+        if "knn_max" in params and params["knn_max"] != self.knn_max:
+            self.knn_max = params["knn_max"]
+            reset_kernel = True
+            del params["knn_max"]
         if "decay" in params and params["decay"] != self.decay:
             self.decay = params["decay"]
             reset_kernel = True
@@ -761,6 +764,7 @@ class PHATE(BaseEstimator):
                 self.graph.set_params(
                     decay=self.decay,
                     knn=self.knn,
+                    knn_max=self.knn_max,
                     distance=self.knn_dist,
                     precomputed=precomputed,
                     n_jobs=self.n_jobs,
@@ -796,7 +800,9 @@ class PHATE(BaseEstimator):
 
         if precomputed is None:
             _logger.info(
-                "Running PHATE on {} observations and {} variables.".format(X.shape[0], X.shape[1])
+                "Running PHATE on {} observations and {} variables.".format(
+                    X.shape[0], X.shape[1]
+                )
             )
         else:
             _logger.info(
@@ -824,6 +830,7 @@ class PHATE(BaseEstimator):
                     distance=self.knn_dist,
                     precomputed=precomputed,
                     knn=self.knn,
+                    knn_max=self.knn_max,
                     decay=self.decay,
                     thresh=1e-4,
                     n_jobs=self.n_jobs,
